tiled.client.dataframe.DataFrameClient
======================================

.. currentmodule:: tiled.client.dataframe

.. autoclass:: DataFrameClient

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DataFrameClient.__init__
      ~DataFrameClient.download
      ~DataFrameClient.export
      ~DataFrameClient.new_variation
      ~DataFrameClient.read
      ~DataFrameClient.read_partition
      ~DataFrameClient.refresh
      ~DataFrameClient.structure
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DataFrameClient.context
      ~DataFrameClient.formats
      ~DataFrameClient.item
      ~DataFrameClient.metadata
      ~DataFrameClient.offline
      ~DataFrameClient.path
      ~DataFrameClient.uri
      ~DataFrameClient.username
   
   